<?php
/**
 * Logitech functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Logitech
 */
error_reporting(0);

if ( ! function_exists( 'logitech_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function logitech_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on _s, use a find and replace
		 * to change 'logitech' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'logitech', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'logitech' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'image',
			'video',
			'link',
			'quote',
			'gallery',
			'audio',
		) );

		/* Add image sizes */
		add_image_size( 'logitech-post-thumbnail-grid', 600, 400, array( 'center', 'center' ) );
		add_image_size( 'logitech-portfolio-thumbnail-grid', 600, 600, array( 'center', 'center' ) );
		add_image_size( 'logitech-portfolio-thumbnail-grid-wdouble', 1200, 600, array( 'center', 'center' ) );
		add_image_size( 'logitech-portfolio-thumbnail-grid-whdouble', 1200, 1200, array( 'center', 'center' ) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, and column width.
	 	 */
		add_editor_style( array( 'css/editor-style.css', logitech_fonts_url() ) );
		
	}
endif;
add_action( 'after_setup_theme', 'logitech_setup' );


if (!function_exists('logitech_ocdi_files')) :
/**
* OCDI files.
*
* @since 1.0.0
*
* @return array Files.
*/
function logitech_ocdi_files() {

return apply_filters( 'aft_demo_import_files', array(
    array(
        'import_file_name'             => esc_html__( 'Logitech Main', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/main/logitech-main.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/main/logitech-main.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/main/logitech-main.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/main/home1.png',
    ),

        array(
        'import_file_name'             => esc_html__( 'Logitech Corporate', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/corporate/logitech-corporate.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/corporate/logitech-corporate.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/corporate/logitech-corporate.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/corporate/home1.png',

    ),

         array(
        'import_file_name'             => esc_html__( 'Logitech Construction', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/construction/logitech-construct.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/construction/logitech-construct.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/construction/logitech-construct.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/construction/home1.png',

    ),


                    array(
        'import_file_name'             => esc_html__( 'Logitech Health', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/health/logitech-health.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/health/logitech-health.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/health/logitech-health.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/health/home1.png',

    ),


                    array(
        'import_file_name'             => esc_html__( 'Logitech Education', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/education/logitech-education.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/education/logitech-education.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/education/logitech-education.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/education/home1.png',

    ),

                                        array(
        'import_file_name'             => esc_html__( 'Logitech Agency', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/agency/logitech-agency.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/agency/logitech-agency.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/agency/logitech-agency.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/agency/home1.png',

    ),


                                        array(
        'import_file_name'             => esc_html__( 'Logitech Finance', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/finance/logitech-finance.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/finance/logitech-finance.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/finance/logitech-finance.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/finance/home1.png',

    ),


                                        array(
        'import_file_name'             => esc_html__( 'Logitech SEO', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/seo/logitech-seo.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/seo/logitech-seo.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/seo/logitech-seo.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/seo/home1.png',

    ),


                                        array(
        'import_file_name'             => esc_html__( 'Logitech Non Profit', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/nonprofit/logitech-nonprofit.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/nonprofit/logitech-nonprofit.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/nonprofit/logitech-nonprofit.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/nonprofit/home1.png',

    ),

                                          array(
        'import_file_name'             => esc_html__( 'Logitech Gymsports', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/gymsport/logitech-gym.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/gymsport/logitech-gym.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/gymsport/logitech-gym.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/gymsport/home1.png',

    ),

                                          array(
        'import_file_name'             => esc_html__( 'Logitech Dark', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/dark/logitech-dark.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/dark/logitech-dark.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/dark/logitech-dark.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/dark/home1.png',

    ),
	
									      array(
        'import_file_name'             => esc_html__( 'Logitech Automobile', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/automobile/logitech-automobile.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/automobile/logitech-automobile.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/automobile/logitech-automobile.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/automobile/automobile-image.png',

    ),
	
										  array(
        'import_file_name'             => esc_html__( 'Logitech Beauty', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/beauty/logitech-beauty.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/beauty/logitech-beauty.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/beauty/logitech-beauty.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/beauty/beauty-image.png',

    ),
	
										  array(
        'import_file_name'             => esc_html__( 'Logitech Building', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/building/logitech-building.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/building/logitech-building.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/building/logitech-building.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/building/building-image.png',

    ),
	
										   array(
        'import_file_name'             => esc_html__( 'Logitech Cleaning', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/cleaning/logitech-cleaning.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/cleaning/logitech-cleaning.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/cleaning/logitech-cleaning.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/cleaning/cleaning-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Software Company', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/software-company/logitech-software.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/software-company/logitech-software.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/software-company/logitech-software.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/software-company/software-image.png',

    ),
	
										    array(
        'import_file_name'             => esc_html__( 'Logitech Garden', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/garden/logitech-garden.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/garden/logitech-garden.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/garden/logitech-garden.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/garden/garden-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Mobile', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/mobile/logitech-mobile.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/mobile/logitech-mobile.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/mobile/logitech-mobile.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/mobile/mobile-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Hosting', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/hosting/logitech-hosting.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/hosting/logitech-hosting.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/hosting/logitech-hosting.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/hosting/hosting-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Hospital', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/hospital/logitech-hospital.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/hospital/logitech-hospital.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/hospital/logitech-hospital.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/hospital/hospital-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Lawyer', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/lawyer/logitech-lawyer.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/lawyer/logitech-lawyer.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/lawyer/logitech-lawyer.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/lawyer/lawyer-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Photography', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/photography/logitech-photography.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/photography/logitech-photography.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/photography/logitech-photography.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/photography/photograph-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Sports', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/sports/logitech-sport.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/sports/logitech-sport.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/sports/logitech-sport.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/sports/sports-image.png',

    ),
	
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Wedding', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/wedding/logitech-wedding.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/wedding/logitech-wedding.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/wedding/logitech-wedding.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/wedding/wedding-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Religion', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/religion/logitech religion.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/religion/logitech religion.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/religion/logitech religion.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/religion/religion-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Restaurant', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/restaurant/logitech-restaurant.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/restaurant/logitech-restaurant.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/restaurant/logitech-restaurant.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/restaurant/restaurant-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Company', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/company/logitech-company.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/company/logitech-company.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/company/logitech-company.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/company/company-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Marketing', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/marketing/logitech-marketing.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/marketing/logitech-marketing.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/marketing/logitech-marketing.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/marketing/marketing-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Enterprise', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/enterprise/logitech-enterprise.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/enterprise/logitech-enterprise.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/enterprise/logitech-enterprise.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/enterprise/enterprise-image.png',

    ),
	
											array(
        'import_file_name'             => esc_html__( 'Logitech Events', 'logitech' ),
        'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/backend/data/events/logitech-event.xml',
        'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/backend/data/events/logitech-event.wie',
        'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/backend/data/events/logitech-event.dat',
        'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'inc/backend/data/events/event-image.png',

    ),
	
	

            
));
}
endif;
add_filter( 'pt-ocdi/import_files', 'logitech_ocdi_files');
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function logitech_widgets_init() {
	/* Register the 'primary' sidebar. */
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'logitech' ),
		'id'            => 'primary',
		'description'   => esc_html__( 'Add widgets here.', 'logitech' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	) );
	/* Repeat register_sidebar() code for additional sidebars. */
}
add_action( 'widgets_init', 'logitech_widgets_init' );

/**
 * Register custom fonts.
 */
if ( ! function_exists( 'logitech_fonts_url' ) ) :
/**
 * Register Google fonts for Blessing.
 *
 * Create your own logitech_fonts_url() function to override in a child theme.
 *
 * @since Blessing 1.0
 *
 * @return string Google fonts URL for the theme.
 */
function logitech_fonts_url() {
	$fonts_url = '';
	$font_families     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Roboto Slab, translate this to 'off'. Do not translate into your own language. */

	$body_font = logitech_get_option( 'body_typo', [] );
	$second_font = logitech_get_option( 'second_font', [] );

	if ( $body_font['font-family'] == '' ) {
		$font_families[] = 'Open Sans:300,300i,400,400i,600,600i,700,700i,800,800i';
	}

	if ( $second_font['font-family'] == '' ) {
		$font_families[] = 'Inter:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	}

	if ( $font_families ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}
	return esc_url_raw( $fonts_url );
}
endif;

/**
 * Enqueue scripts and styles.
 */
function logitech_scripts() {

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'logitech-fonts', logitech_fonts_url(), array(), null );

	/** All frontend css files **/ 
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), '4.0', 'all');
	
	/** load fonts icons **/
    wp_enqueue_style( 'logitech-flaticon', get_template_directory_uri().'/css/flaticon.css');

    /** Owl slider **/
	wp_enqueue_style( 'owl-slider', get_template_directory_uri().'/css/owl.carousel.min.css');
	
	/** Lightgallery Popup **/
    wp_enqueue_style( 'lightgallery', get_template_directory_uri().'/css/lightgallery.css');

	/** Theme stylesheet. **/
	wp_enqueue_style( 'logitech-style', get_stylesheet_uri() );	

	if( logitech_get_option('preload') != false ){
		wp_enqueue_script( 'royal-preloader', get_template_directory_uri()."/js/royal_preloader.min.js", array('jquery'), '20200716', true);
	}

	wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/js/jquery.isotope.min.js', array('jquery'), '20200716',  true );
	wp_enqueue_script( 'lightgallery', get_template_directory_uri() . '/js/lightgallery-all.min.js', array( 'jquery' ), '20200716', true );
	wp_enqueue_script( 'owl-slider', get_template_directory_uri() . '/js/owl.carousel.min.js', array( 'jquery' ), '20200716', true );
	wp_enqueue_script( 'easypiechart', get_template_directory_uri() . '/js/easypiechart.min.js', array( 'jquery' ), '20200716', true );
	wp_enqueue_script( 'countdown', get_template_directory_uri() . '/js/jquery.countdown.min.js', array( 'jquery' ), '20180910', true );
    wp_enqueue_script( 'logitech-elementor', get_template_directory_uri() . '/js/elementor.js', array( 'jquery' ), '20200716', true );
	wp_enqueue_script( 'logitech-elementor-header', get_template_directory_uri() . '/js/elementor-header.js', array('jquery'), '20200716', true );
	wp_enqueue_script( 'logitech-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), '20200716', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'logitech_scripts' );



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/frontend/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/frontend/template-functions.php';

/**
 * Custom Page Header for this theme.
 */
require get_template_directory() . '/inc/frontend/page-header/breadcrumbs.php';
require get_template_directory() . '/inc/frontend/page-header/page-header.php';

/**
 * Functions which add more to backend.
 */
require get_template_directory() . '/inc/backend/admin-functions.php';

/**
 * Custom metabox for this theme.
 */
require get_template_directory() . '/inc/backend/meta-boxes.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/backend/customizer/customizer.php';

/**
 * Register the required plugins for this theme.
 */
require get_template_directory() . '/inc/backend/plugin-requires.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/backend/color.php';

/**
 * Preloader js & css
 */
require get_template_directory() . '/inc/frontend/preloader.php';

/**
 * Elementor functions.
 */

require get_template_directory() . '/inc/backend/elementor/elementor.php';
require get_template_directory() . '/inc/frontend/builder.php';

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'woocommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce/woocommerce.php';
}